@@ -1,7 +1,8 @@
 #!/bin/bash
-VERSION='0.4.0'
+VERSION='0.6'
 #
-# Copyright (C) 2003-2007  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2003-2008  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 # Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
 # Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 # Copyright (C) 2002       Mark Lawrence <nomad@null.net>
@@ -60,8 +61,8 @@ REMOVE_PACKAGES="lilo,makedev,nfs-kernel-server,lpr"
 ARCH=""
 
 # Which debian distribution
-# (warning: this has only been tested with woody, sarge and etch)
-DIST="etch"
+# (warning: this has only been tested with woody, sarge, etch and lenny)
+DIST="lenny"
 
 # Local or nearest location of a debian mirror (must include the `/debian')
 MIRROR="http://ftp.uk.debian.org/debian"
@@ -119,7 +120,7 @@ Options:
         -V, --version		copyright and version information
 	--arch			set target architecture (eg. --arch "i386")
 				(autodetected on Debian host if dpkg available)
-	--dist			defaults to "etch", passed to debootstrap.
+	--dist			defaults to "lenny", passed to debootstrap.
 	--context n             Set the context id to be used.
 	--fakeinit		use "/sbin/init" to boot vserver
 	--conffile		extra configuration file to load.
@@ -147,7 +148,8 @@ full_version ()
 {
     cat << EOF
 ${0##*/} version $VERSION
-Copyright (C) 2003-2007  Ola Lundqvist <opal@debian.org>
+Copyright (C) 2003-2008  Ola Lundqvist <opal@debian.org>
+Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
 Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 Copyright (C) 2002       Mark Lawrence <nomad@null.net>
@@ -209,13 +211,13 @@ parse_args ()
 			case "$2" in
 			    [a-z]*)
 				DIST="$2"
-				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] ; then
-				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\" and \"etch\", be careful!" 1>&2
+				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] && [ "lenny" != "$2" ] ; then
+				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\", \"etch\" and \"lenny\", be careful!" 1>&2
 				fi
 				;;
 			    *)
 				echo "${0##*/} error: $1 requires a Debian distribution" 1>&2
-				echo 'e.g. "woody", "sarge" or "etch"' 1>&2
+				echo 'e.g. "woody", "sarge", "etch" or "lenny"' 1>&2
 				exit 1
 				;;
 			esac
@@ -430,15 +432,49 @@ if [ -n "$CONTEXT" ] ; then
 fi
 
 ## use "vserver ... build" to build the new vserver
-if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
-       --rootdir "$VROOTDIR" --hostname "$VHOST" --interface "$INTERFACE:$IP" \
-       $CONTEXT_ARGUMENT \
-       -- -d "$DIST" -m "$MIRROR" \
-       -- $ARCH_ARGUMENT \
-       --include="$INSTALL_PACKAGES" --exclude="$REMOVE_PACKAGES"
-  then
-    echo "${0##*/}: error: vserver-build failure. Cannot continue."
-    exit 1
+if [ -n "$INSTALL_PACKAGES" ] && [ -n "$REMOVE_PACKAGES" ] ; then
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT \
+	    --include="$INSTALL_PACKAGES" --exclude="$REMOVE_PACKAGES" ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
+elif [ -n "$INSTALL_PACKAGES" ] && [ -z "$REMOVE_PACKAGES" ] ; then
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT \
+	    --include="$INSTALL_PACKAGES" ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
+elif [ -z "$INSTALL_PACKAGES" ] && [ -n "$REMOVE_PACKAGES" ] ; then
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT \
+	    --exclude="$REMOVE_PACKAGES" ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
+else
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
 fi
 
 # Create a locale.gen if needed.
@@ -518,7 +554,7 @@ EOF
 
 # grab DNS servers from the host-server for `resolv.conf'
 HOST_IP=$(ip -o addr show dev $INTERFACE primary scope global | \
-          sed -n 's;.*inet \([^/]*\)/.*;\1;p')
+          sed -n 's;.*inet \([^/]*\)/.*;\1;p'  | head -1)
 (echo search $VDOMAIN;
  grep '^nameserver' /etc/resolv.conf | sed "s/127.0.0.1/$HOST_IP/") \
     > "$VROOTDIR/$VHOST/etc/resolv.conf"
