@@ -1,7 +1,9 @@
 #!/bin/bash
-VERSION='0.4.0'
+VERSION='0.6'
 #
-# Copyright (C) 2002-2007  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2008       Vincent Bernat <bernat@luffy.cx>
+# Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
 # Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
 # Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 # Copyright (C) 2005       Thomas Gelf <thomas@gelf.net>
@@ -57,16 +59,20 @@ REMOVE_PACKAGES="sparc-utils,dhcp-client,lilo,makedev,pcmcia-cs,ppp,pppconfig,pp
 # sysvinit services relating to hardware access to remove
 REMOVE_LINKS="klogd hwclock.sh setserial urandom networking umountfs halt reboot mountvirtfs mountall.sh mountnfs.sh ifupdown"
 
-# Post installation script
+# Post installation script, run inside vserver guest context
 POST_INSTALL_SCRIPT=""
 
+# Post installation script, run inside vserver host context and before
+# POST_INSTALL_SCRIPT
+POST_INSTALL_HOST_SCRIPT=""
+
 # Architecture: overide on non-Debian host such as Redhat
 # otherwise dpkg will detect whether we are i386/powerpc/sparc/etc
 ARCH=""
 
 # Which debian distribution
-# (warning: this has only been tested with woody, sarge and etch)
-DIST="etch"
+# (warning: this has only been tested with woody, sarge, etch and lenny)
+DIST="lenny"
 
 # Local or nearest location of a debian mirror (must include the `/debian')
 MIRROR="http://ftp.uk.debian.org/debian"
@@ -118,7 +124,7 @@ Options:
         -V, --version		copyright and version information
 	--arch			set target architecture (eg. --arch "i386")
 				(autodetected on Debian host if dpkg available)
-	--dist			defaults to "etch", passed to debootstrap.
+	--dist			defaults to "lenny", passed to debootstrap.
 	--context n             Set the context id to be used.
 	--fakeinit		use "/sbin/init" to boot vserver
 	--conffile		extra configuration file to load.
@@ -147,13 +153,15 @@ full_version ()
 {
     cat << EOF
 ${0##*/} version $VERSION
-Copyright (C) 2002-2007 Ola Lundqvist <opal@debian.org>
-Copyright (C) 2007      Jochen Voss <voss@seehuhn.de>
-Copyright (C) 2006      Miroslav Kure <kurem@upcase.inf.upol.cz>
-Copyright (C) 2005      Thomas Gelf <thomas@gelf.net>
-Copyright (C) 2005      Daniel Hermann <hermann@tkm.physik.uni-karlsruhe.de>
-Copyright (C) 2002      Paul Sladen   <vserver@paul.sladen.org>
-Copyright (C) 2002      Mark Lawrence <nomad@null.net>
+Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
+Copyright (C) 2008       Vincent Bernat <bernat@luffy.cx>
+Copyright (C) 2007       Tijs van Dam <tijsvd@bluescraper.com>
+Copyright (C) 2007       Jochen Voss <voss@seehuhn.de>
+Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
+Copyright (C) 2005       Thomas Gelf <thomas@gelf.net>
+Copyright (C) 2005       Daniel Hermann <hermann@tkm.physik.uni-karlsruhe.de>
+Copyright (C) 2002       Paul Sladen   <vserver@paul.sladen.org>
+Copyright (C) 2002       Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -213,17 +221,27 @@ parse_args ()
                        fi
                        shift 2
                        ;;
+                   --post-install-host-script)
+                       if [ -r "$2" ] ; then
+                           POST_INSTALL_HOST_SCRIPT="$2"
+                           echo "Script $2 found."
+                       else
+                           echo "Error, can not locate the script $2."
+                           exit 1
+                       fi
+                       shift 2
+                       ;;
 		    --dist)
 			case "$2" in
 			    [a-z]*)
 				DIST="$2"
-				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] ; then
-				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\" and \"etch\", be careful!" 1>&2
+				if [ "sarge" != "$2" ] && [ "woody" != "$2" ] && [ "etch" != "$2" ] && [ "lenny" != "$2" ] ; then
+				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\", \"etch\" and \"lenny\", be careful!" 1>&2
 				fi
 				;;
 			    *)
 				echo "${0##*/} error: $1 requires a Debian distribution" 1>&2
-				echo 'e.g. "woody", "sarge" or "etch"' 1>&2
+				echo 'e.g. "woody", "sarge", "etch" or "lenny"' 1>&2
 				exit 1
 				;;
 			esac
@@ -405,7 +423,7 @@ fi
 aptcleanup() {
     apt-get autoclean -o Dir::Cache::Archives="$1"
     OLD=""
-    for P in $(find "$1" -name *.deb -printf "%f\n" -mindepth 1 -maxdepth 1 | sed -e "s/_.*//;") ; do
+    for P in $(find "$1" -mindepth 1 -maxdepth 1 -name *.deb -printf "%f\n" | sed -e "s/_.*//;") ; do
 	if [ "$P" == "$OLD" ] ; then
 	    rm -f "$1"/$P_* > /dev/null 2>&1
 	fi
@@ -437,15 +455,49 @@ if [ -n "$CONTEXT" ] ; then
 fi
 
 ## use "vserver ... build" to build the new vserver
-if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
-       --rootdir "$VROOTDIR" --hostname "$VHOST" --interface "$INTERFACE:$IP" \
-       $CONTEXT_ARGUMENT \
-       -- -d "$DIST" -m "$MIRROR" \
-       -- $ARCH_ARGUMENT \
-       --include="$INSTALL_PACKAGES" --exclude="$REMOVE_PACKAGES"
-  then
-    echo "${0##*/}: error: vserver-build failure. Cannot continue."
-    exit 1
+if [ -n "$INSTALL_PACKAGES" ] && [ -n "$REMOVE_PACKAGES" ] ; then
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT \
+	    --include="$INSTALL_PACKAGES" --exclude="$REMOVE_PACKAGES" ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
+elif [ -n "$INSTALL_PACKAGES" ] && [ -z "$REMOVE_PACKAGES" ] ; then
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT \
+	    --include="$INSTALL_PACKAGES" ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
+elif [ -z "$INSTALL_PACKAGES" ] && [ -n "$REMOVE_PACKAGES" ] ; then
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT \
+	    --exclude="$REMOVE_PACKAGES" ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
+else
+    if ! /usr/sbin/vserver "$VHOST" build -m debootstrap \
+	    --rootdir "$VROOTDIR" --hostname "$VHOST" \
+	    --interface "$INTERFACE:$IP" \
+	    $CONTEXT_ARGUMENT \
+	    -- -d "$DIST" -m "$MIRROR" \
+	    -- $ARCH_ARGUMENT ; then
+	echo "${0##*/}: error: vserver-build failure. Cannot continue."
+	exit 1
+    fi
 fi
 
 # Create a locale.gen if needed.
@@ -508,7 +560,7 @@ EOF
 
 # grab DNS servers from the host-server for `resolv.conf'
 HOST_IP=$(ip -o addr show dev $INTERFACE primary scope global | \
-          sed -n 's;.*inet \([^/]*\)/.*;\1;p')
+          sed -n 's;.*inet \([^/]*\)/.*;\1;p' | head -1)
 (echo search $VDOMAIN;
  grep '^nameserver' /etc/resolv.conf | sed "s/127.0.0.1/$HOST_IP/") \
     > "$VROOTDIR/$VHOST/etc/resolv.conf"
@@ -641,6 +693,11 @@ $EXTRA_PACKAGES_INSTALL
 
 EOF
 
+# Run the post-installation script from outside the server
+if [ -n "$POST_INSTALL_HOST_SCRIPT" ]; then
+    "$POST_INSTALL_HOST_SCRIPT"
+fi
+
 ## start vserver before we can exec anything inside it
 vserver $VHOST start
 
