@@ -1,7 +1,7 @@
 #!/bin/bash
-VERSION='0.4.0'
+VERSION='0.6'
 #
-# Copyright (C) 2002-2007  Ola Lundqvist <opal@debian.org>
+# Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
 # Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 # Copyright (C) 2002       Mark Lawrence <nomad@null.net>
 # Copyright (C) 2002       Paul Sladen   <vserver@paul.sladen.org>
@@ -52,10 +52,6 @@ REMOVE_PACKAGES="dhcp-client,lilo,makedev,pcmcia-cs,ppp,pppconfig,pppoe,pppoecon
 # sysvinit services relating to hardware access to remove
 REMOVE_LINKS="klogd hwclock.sh setserial urandom networking umountfs halt reboot"
 
-# Which debian distribution
-# (warning: this has only been tested with woody, sarge and etch)
-DIST="etch"
-
 # Default network interface for vservers:
 INTERFACE="eth0"
 
@@ -102,7 +98,7 @@ Options:
 				(autodetected on Debian host if dpkg available)
 	--copy-vreboot		install "vreboot/vshutdown/vhalt"
 	--no-copy-vreboot	don't install "vreboot/vshutdown/vhalt"
-	--dist			defaults to "etch", passed to debootstrap.
+	--dist			Depricated option.
 	--fakeinit		use "/sbin/init" to boot vserver
 	--conffile		extra configuration file to load.
 	--interface		interface for IP addresses (if not "eth0")
@@ -121,7 +117,7 @@ full_version ()
 {
     cat << EOF
 ${0##*/} version $VERSION
-Copyright (C) 2002-2007  Ola Lundqvist <opal@debian.org>
+Copyright (C) 2002-2008  Ola Lundqvist <opal@debian.org>
 Copyright (C) 2006       Miroslav Kure <kurem@upcase.inf.upol.cz>
 Copyright (C) 2002       Mark Lawrence <nomad@null.net>
 Copyright (C) 2002       Paul Sladen   <vserver@paul.sladen.org>
@@ -166,19 +162,7 @@ parse_args ()
 			shift
 			;;
 		    --dist)
-			case "$2" in
-			    [a-z]*)
-				DIST="$2"
-				if [ "woody" != "$2" ] && [ "sarge" != "$2" ] && [ "etch" != "$2" ] ; then
-				    echo "${0##*/} warning: I only know how to do \"woody\", \"sarge\" and \"etch\", be careful!" 1>&2
-				fi
-				;;
-			    *)
-				echo "${0##*/} error: $1 requires a Debian distribution" 1>&2
-				echo 'e.g. "woody", "sarge" or "etch"' 1>&2
-				exit 1
-				;;
-			esac
+		        echo -- "--dist is a depciated option for stripserver."
 			shift 2
 			;;
 		    --domain)
